@@ -14,7 +14,7 @@ use Carp;
 use CBOR::XS qw(encode_cbor decode_cbor);
 use base 'Tie::Hash';
 
-our $VERSION = '0.003';    # VERSION
+our $VERSION = '0.004';    # VERSION
 
 sub TIEHASH {
     my ( $class, $redis, $prefix ) = @_;
@@ -38,7 +38,9 @@ sub STORE {
 
 sub FETCH {
     my ( $self, $key ) = @_;
-    decode_cbor( $self->{redis}->get( $self->{prefix} . $key ) );
+    my $data = $self->{redis}->get( $self->{prefix} . $key );
+    return unless defined $data;
+    decode_cbor($data);
 }
 
 sub FIRSTKEY {
@@ -86,7 +88,7 @@ Tie::Redis::Candy::Hash - tie Perl hashes to Redis hashes - the candy way
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 DESCRIPTION
 
